@@ -3,6 +3,7 @@ import logging
 
 _logger = logging.getLogger(__name__)
 
+
 class DataInputStream:
     def __init__(self, stream):
         self.stream = stream
@@ -96,18 +97,18 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
     return value_array
 
 
-def read_rows_from_batch(query_columns_description: list, dis: DataInputStream) -> list:
-    rows = list()
+def read_rows_from_batch(query_columns_description: list, dis: DataInputStream):
     is_row_present = dis.read_byte()
-
+    if not is_row_present:
+        return None
+    rows = list()
     while is_row_present == 1:
         if is_row_present:
             row = read_values_from_array(query_columns_description, dis)
             rows.append(row)
-        #   if rows become 1000, break it
+            #   if rows become 1000, break it
             if len(rows) == 1000:
                 _logger.info("Read Batch - Breaking the loop after 1000 records")
                 break
         is_row_present = dis.read_byte()
-
     return rows
