@@ -315,7 +315,7 @@ class Cursor(DBAPICursor):
     def _fetch_all(self):
         _logger.info("fetching all from overriden method")
         self._data = list()
-        while len(self._data) < self.rowcount():
+        while True:
             _logger.info(len(self._data))
             _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
@@ -346,9 +346,7 @@ class Cursor(DBAPICursor):
         _logger.info("fetching all from overriden method")
         if size is None:
             size = self.arraysize
-        size = min(size, self.rowcount())
-        if self._data is None:
-            self._data = list()
+        self._data = list()
         while len(self._data) < size:
             _logger.info("fetching next batch from fetch many")
             rows = self.fetch_batch()
@@ -356,7 +354,7 @@ class Cursor(DBAPICursor):
                 break
             self._data += rows
         _logger.info(len(self._data))
-        if len(self._data) == size:
+        if len(self._data) <= size:
             rows = self._data
             self._data = None
             return rows
